@@ -29,7 +29,9 @@ class Span:
             name: str,
             child_of=None,
             span_id: Optional[str] = None,
-            trace_id: Optional[str] = None
+            trace_id: Optional[str] = None,
+            event_id: Optional[str] = None,
+            context_id: Optional[str] = None
     ):
         self.name: str = name
         self.child_of: Span = child_of
@@ -42,11 +44,23 @@ class Span:
             self.span_id: str = str(uuid())
 
         if child_of is None:
+            self.event_id = event_id
+            self.context_id = context_id
             self.trace_id = trace_id
+
+            if self.event_id is None:
+                self.event_id = str(uuid())
+                logger.warning(f"no event_id specified, generating one: {self.event_id}")
+
+            if self.context_id is None:
+                self.context_id = self.event_id
+
             if self.trace_id is None:
                 self.trace_id = str(uuid())
         else:
             self.trace_id = child_of.trace_id
+            self.event_id = child_of.event_id
+            self.context_id = child_of.context_id
 
     def log_kv(self, kv: dict):
         self.context = kv
@@ -58,6 +72,8 @@ class Span:
             "created_at": self.created_at,
             "service_name": self.service_name,
             "trace_id": self.trace_id,
+            "event_id": self.event_id,
+            "context_id": self.context_id,
             "status": status,
             "elapsed": elapsed,
             "error_msg": error_msg
@@ -65,8 +81,11 @@ class Span:
 
         if self.child_of:
             event["child_of"] = self.child_of.span_id
+
         if self.context:
             event["context"] = self.context
+        else:
+            event["context"] = dict()
 
         return event
 
@@ -93,13 +112,27 @@ class Tracer:
         if self.logging:
             logger.info(f"[{status}] elapsed {elapsed:.4f}s, reporting span: {span}")
 
-        binary_event = bytes(json.dumps(span.to_event(elapsed, status, error_msg)), "utf-8")
-        self.udp_socket.send(binary_event)
+        try:
+            binary_event = bytes(json.dumps(span.to_event(elapsed, status, error_msg)), "utf-8")
+        except Exception as e:
+            logger.error(f"could not convert span to event: {str(e)}")
+            return
+
+        try:
+            self.udp_socket.send(binary_event)
+        except Exception as e:
+            logger.error(f"could not send event to socket: {str(e)}")
 
     @contextmanager
-    def start_span(self, name: str, child_of: Optional[Span] = None):
+    def start_span(
+            self,
+            name: str,
+            child_of: Optional[Span] = None,
+            event_id: Optional[str] = None,
+            context_id: Optional[str] = None
+    ):
         start = perf_counter()
-        span = Span(self.service_name, name, child_of)
+        span = Span(self.service_name, name, child_of, event_id=event_id, context_id=context_id)
         status = "ok"
         error_msg = ""
 
